@@ -2,4 +2,6 @@ from .diceloss.dice import DiceLoss, DiceCELoss
 from .diceloss.tfdice import TFDiceLoss
 from .iouloss.iou import IoULoss
 from .iouloss.tfiou import TFIoULoss
+from .tversky.tversky import TverskyLoss
+from .tversky.tftversky import TFTverskyLoss
 
